BuzHashIncr

Struct BuzHashIncr 

pub struct BuzHashIncr<H: BuzHashHash> { /* private fields */ }
Self-contained buzhash which buffers it’s window of values internally

Note that this will be less efficient than using BuzHash on a slice directly, but may be more convenient.