ToChunkIncr

Trait ToChunkIncr 

pub trait ToChunkIncr {
    type Incr: ChunkIncr;

    // Required method
    fn to_chunk_incr(&self) -> Self::Incr;
}
Implimented on types which can be converted to/can provide a ChunkIncr interface.

Types that impliment this generally represent a instantiation of a chunking algorithm.

Required Associated Types

type Incr: ChunkIncr

Incr provides the incrimental interface to this chunking instance

Required Methods

fn to_chunk_incr(&self) -> Self::Incr

to_chunk_incr() returns a ChunkIncr which can be incrimentally fed data and emits chunks.

Generally, this is a typically low cost operation that copies from the implimentor or does minor computation on its fields and may allocate some memory for storing additional state needed for incrimental computation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors