ZstdIncr

Struct ZstdIncr 

pub struct ZstdIncr { /* private fields */ }
Incrimental chunking using Zstd’s rsyncable algorithm

Performance note: Zstd’s chunking requires buffer look back to remove previously inserted data, and as a result requires ZstdIncr to maintain an internal buffer. This internal buffer may reduce performance.