pub struct BuzHash<H: BuzHashHash> { /* private fields */ }Expand description
Describes an instance of BuzHash (aka cyclic polynomial hash).
Provides parameterization over the window size (k), hash function (h), chunk edge mask, and
max chunk size.
Uses fixed 32-bit width for the hash.
The trait BuzHashHash provides the internal hash function, see the implimentations of it
for built-in hash options (which include both Borg and silvasur/buzhash’s internal hash
tables).
Note that it’s helpful for k to be prime to prevent repeating strings form resulting
in total cancelation of the internal hash, which can cause overly long chunks.
Adjusting mask changes the average chunk size.
Performance
BuzHash requires storing bytes equal to it’s window size (k). Because of this,
BuzHashIncr may have poor performance compared to BuzHash::find_chunk_edge().
Implementations
Sourceimpl<H: BuzHashHash> BuzHash<H>
impl<H: BuzHashHash> BuzHash<H>
Sourcepub fn new(capacity: usize, mask: u32, hash: H, max_chunk_size: u64) -> Self
pub fn new(capacity: usize, mask: u32, hash: H, max_chunk_size: u64) -> Self
Create an instance with the given capacity (k) and chunk termination mask, and a internal
hash function.
capacity is the number of bytes that are taken into account for a given hash.
mask affects how chunk edges are determined.
hash is applied to each byte of input prior to mixing into the rolling hash.